# Auto Py to Exe

Auto Py to Exe easily converts python scripts to executable files.

Simply select your script location and choose other settings that are given in the GUI. When finished click the big blue convert button and wait while the output is displayed.

The output will say when it is complete and you will be able to clear the output if you want to make a small change and re-convert.

# Script Location

# Onefile

# Console Window

# Icon

# Additional Files

Be careful when using additional files with onefile mode; read this and update your code to work with pyinstaller.

If you want to put additional files in the root directory, put a period (.) in the destination.

# Advanced

Output Directory:

## General Options

--upx-dir
--log-level
-n

## What to bundle, where to search

--add-binary
-p
--hidden-import
--additional-hooks-dir
--runtime-hook
--exclude-module
--key

## How to generate

--debug

## Windows specific options

--version-file
-m
-r

## Windows Side-by-side Assembly searching options

## Mac OS X specific options

--osx-bundle-identifier

## Rarely used special options

--runtime-tmpdir
Extra Command Data:

# Current Command

# Output

Something wrong with your exe? Read this post on how to fix common issues for possible solutions.